import {Component, OnInit, ViewChild} from '@angular/core';
import {IonSlides} from "@ionic/angular";
import {CommonService} from "../../../provide/common.service";
import {Badge} from "@ionic-native/badge/ngx";
import {CalendarComponentOptions,DayConfig} from "ion2-calendar";
import {Storage} from "@ionic/storage";
import {TabsService} from "../tabs.service";
import {AppService,AppGlobal} from "../../../http/http.service";
import {monthCh,weekDay} from "../../../main";
import {Router} from "@angular/router";

@Component({
  selector: 'app-serve',
  templateUrl: './serve.page.html',
  styleUrls: ['./serve.page.scss'],
})
export class ServePage {

  slideOpts = {
    initialSlide: 1,
    speed: 400
  };
  slidersItems = [];
  hasNew = {
    activity:0,
    notice:0,
    premanager:0,
    message:0,
    test:0,
  };

  //日历
  date: string;
  type: 'string';

  optionsMulti: CalendarComponentOptions;
  newArr: DayConfig[] = [];

  //未读通知
  NoticeNotreadCount = '0';
  //尚未报备
  PremanagerNotdoCount = '0';
  //是否显示正在开发中
  isWait: boolean = false;

  noticeList = [];

  picture: string = AppGlobal.picture;

  operations: Array<string>;

  //当前年份
  year;
  //当前月份
  month;
  //当前第几周
  weekNo;

  noticeTips;
  role;

  constructor(public commonSer:CommonService,public router:Router,
              public appService: AppService,  public storage: Storage,
              public badge: Badge, public tabsSer: TabsService) {

  }

  ionViewDidEnter() {
    this.tabsSer.findAllActivityForAppWithXQ().subscribe(
        (res)=>{
          this.noticeList = res.slice(0, 2);
        }
    )
    //获取权限
    this.getRole();
    //获取消息数量
    this.getNewCount();
    //获取日历
    this.getCalendar();
  }

  ionViewWillEnter() {
    this.slidersItems = [];
    this.getHasNew();
    //轮播图
    this.tabsSer.getBanner().subscribe(
        (res)=>{
          this.slidersItems = res;
          console.log(this.slidersItems)
        }
    )

  }

  ionViewDidLeave() {
    this.newArr = [];
    // if (this.slides) {
    //   this.slides.stopAutoplay();
    // }
  }


  //获取权限
  getRole() {
    this.tabsSer.getRoles().subscribe(
        (res) => {
          this.role = res
        },
        error => {
          this.commonSer.alert('系统错误！');
        }
    )
  }

  wait() {
    this.isWait = true;
  }

  cancleWait() {
    this.isWait = false;
  }


  go(item) {
    if (item.type == 1) {
      this.getActivity(item.id);
    } else if (item.type == 2) {
      this.getPremanager(item.id);
    } else if (item.type == 3) {
      // this.navCtrl.push("AnnouncementViewPage", {
      //   id: item.id
      // });
    }
  }

  //获取活动ById
  getActivity(id) {
    this.appService.ObserverHttpPost("/wisdomgroup/modules/activity/appFindById", {id: id})
        .toPromise()
        .then(res => {
          let activity = res.json();
          // this.router.navigate([])
          // this.navCtrl.push('ActivityDetailPage', {id: activity.id});
        })
        .catch(error => {
        });
  }


  //获取报备
  getPremanager(id) {
    this.storage.remove("temp_userpre");
    this.storage.remove("managerId");
    this.storage.remove("city");
    this.storage.remove("cityList");
    this.storage.remove("person");
    this.appService.ObserverHttpPost("/wisdomgroup/modules/premanager/findById", {id: id}).subscribe((res) => {
      let premanager = res.json();
      this.storage.set("premanager", premanager);
      // this.navCtrl.push("OutGoingReportEditPage");
    })
  }

  //消息通知
  gotoNotice() {
    // this.navCtrl.setRoot(NoticePage);
    // this.navCtrl.parent.select(2);
  }

  //外出报备跳转
  goOutGoingReportAboutAll() {
    // this.navCtrl.push("OutGoingReportPage", {
    //   type: 1
    // });
  }

  //前往
  goTo(page) {
    // this.navCtrl.push(page);
  }


  /**
   * 获取是否有新的信息
   */
  getHasNew(){
    //获取是否有新活动
    this.tabsSer.hasNewActivity().subscribe(
        (res)=>{
          this.hasNew.activity = res;
        }
    )

    //获取是否有新通知
    this.tabsSer.hasNewNotice().subscribe(
        (res)=>{
          this.hasNew.notice = res;
        }
    )

    //获取是否有新通知
    this.tabsSer.hasNewMessage().subscribe(
        (res)=>{
          this.hasNew.message = res;
        }
    )

    //获取是否有新报备
    this.tabsSer.hasNewPremanager().subscribe(
        (res)=>{
          this.hasNew.premanager = res;
        }
    )

    //获取是否有新问卷
    this.tabsSer.hasNewTest().subscribe(
        (res)=>{
          this.hasNew.test = res;
        }
    )
  }

  //获取所有未读消息的数量--->设置角标
  getNewCount() {
    this.appService.ObserverHttpGetData('/wisdomgroup/modules/activity/hasNewCount', null)
        .subscribe((res) => {
          let data = Number(res.json());
          this.noticeTips = data;
          console.log(this.noticeTips)
          if (data > 0) {
            this.badge.set(data);
          } else {
            this.badge.clear();
          }
        })
  }

  //日历

  getCalendar() {
    this.newArr = [];
    let date = new Date();
    let year = date.getFullYear();
    let month = date.getMonth() + 1;

    //2.参加活动日期
    this.tabsSer.appOrderCal().subscribe(
        (order)=>{
          order.forEach(event => {
            this.newArr.push({
              date: new Date(event.batch.batchGoDate),
              disable: true,
              cssClass: 'dayOff2'
            })
          });

          this.tabsSer.appPreCal().subscribe(
              (pre)=>{
                pre.forEach(event => {
                  this.newArr.push({
                    date: new Date(event.formshTime),
                    disable: true,
                    cssClass: 'dayOff4'
                  })
                });

                this.loadEvent(year, month);
              }
          )
        }
    );
  }

  loadEvent(year, month) {
    //5.获取每月值班信息
    const data = {
      date: year + '/' + month + '/01'
    };
    this.tabsSer.getMyScheduleOnMonth(data).subscribe(
        (schedule)=>{
          for (let i = 0; i < schedule.length; i++) {
            const ev = {
              date: new Date(schedule[i].dutyDate),
              disable: true,
              cssClass: 'dayOff3'
            };
            this.newArr.push(ev);
          }
          this.tabsSer.getFestivalAboutMonth(data).subscribe(
              (festival)=>{
                festival.forEach(event => {
                  const data = {
                    date: new Date(event.date),
                    disable: true,
                    cssClass: 'dayOff1'
                  };
                  this.newArr.push(data);
                });
                this.setCalendar(year, month);
              }
          )
        }
    )

  }

  setCalendar(year, month) {
    let date = new Date();
    //4.每月的周末
    let d = new Date(year, month, 0).getDate();
    for (let i = 1; i < d + 1; i++) {
      date.setFullYear(year, month - 1, i);
      let day = date.getDay();
      if (day == 6 || day == 0) {
        const data = {
          date: new Date(year, month - 1, i),
          disable: true,
          cssClass: 'dayOff1'
        };
        this.newArr.push(data);
      }
    }

    this.optionsMulti = {
      pickMode: 'multi',
      monthFormat: 'YYYY 年 MM 月 ',
      weekdays: weekDay,
      monthPickerFormat: monthCh,
      weekStart: 0,
      disableWeeks: [0, 1, 2, 3, 4, 5, 6],
      daysConfig: this.newArr
    };
  }

  onChange(e) {
  }

  //月份改变
  monChange(e) {
    this.loadEvent(e.newMonth.years, e.newMonth.months);
  }

}

//定义星期实体
export class Week {
  id: number;
  title: string;
  date: number;
  isToday: boolean = false;
}
